@@ -4,7 +4,15 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.10';
+$VERSION = '0.11';
+
+=encoding utf8
+
+=head1 NAME
+
+Devel::Platform::Info::Linux - Retrieve Linux platform metadata
+
+=cut
 
 #----------------------------------------------------------------------------
 
@@ -422,10 +430,6 @@ sub _release_version {
 
 __END__
 
-=head1 NAME
-
-Devel::Platform::Info::Linux - Retrieve Linux platform metadata
-
 =head1 SYNOPSIS
 
   use Devel::Platform::Info::Linux;
@@ -496,7 +500,7 @@ RT Queue: http://rt.cpan.org/Public/Dist/Display.html?Name=Devel-Platform-Info
 
   Barbie (BARBIE) <barbie@cpan.org>
   Brian McCauley (NOBULL) <nobull67@gmail.com>
-  Colin Newell http://colinnewell.wordpress.com/
+  Colin Newell (NEWELL) <newellc@cpan.org>
   Jon 'JJ' Allen (JONALLEN) <jj@jonallen.info>
 
 =head1 COPYRIGHT & LICENSE
