@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.10';
+$VERSION = '0.11';
 
 #----------------------------------------------------------------------------
 
@@ -138,7 +138,7 @@ RT Queue: http://rt.cpan.org/Public/Dist/Display.html?Name=Devel-Platform-Info
 
   Barbie (BARBIE) <barbie@cpan.org>
   Brian McCauley (NOBULL) <nobull67@gmail.com>
-  Colin Newell http://colinnewell.wordpress.com/
+  Colin Newell (NEWELL) <newellc@cpan.org>
   Jon 'JJ' Allen (JONALLEN) <jj@jonallen.info>
 
 =head1 COPYRIGHT & LICENSE
